@@ -51,7 +51,7 @@ main (void)
 				    0, "1234", &last_otp);
   if (rc != OATH_NO_SUCH_FILE)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[1]: %d\n", rc);
       return 1;
     }
 
@@ -59,7 +59,7 @@ main (void)
 				    0, "1234", &last_otp);
   if (rc != OATH_BAD_PASSWORD)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[2]: %d\n", rc);
       return 1;
     }
 
@@ -67,7 +67,7 @@ main (void)
 				    0, "1234", &last_otp);
   if (rc != OATH_BAD_PASSWORD)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[3]: %d\n", rc);
       return 1;
     }
 
@@ -75,7 +75,7 @@ main (void)
 				    0, "4711", &last_otp);
   if (rc != OATH_OK)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[4]: %d\n", rc);
       return 1;
     }
 
@@ -83,7 +83,7 @@ main (void)
 				    1, "4711", &last_otp);
   if (rc != OATH_OK)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[5]: %d\n", rc);
       return 1;
     }
 
@@ -91,7 +91,7 @@ main (void)
 				    1, "4711", &last_otp);
   if (rc != OATH_OK)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[6]: %d\n", rc);
       return 1;
     }
 
@@ -99,10 +99,10 @@ main (void)
 				    "foo", "755224", 0, "8989", &last_otp);
   if (rc != OATH_REPLAYED_OTP)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[7]: %d\n", rc);
       return 1;
     }
-  if (last_otp != 1260203142)
+  if (last_otp != 1260206742)
     {
       printf ("oath_authenticate_usersfile timestamp %d != 1260203142\n",
 	      last_otp);
@@ -113,7 +113,7 @@ main (void)
 				    "rms", "755224", 0, "4321", &last_otp);
   if (rc != OATH_BAD_PASSWORD)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[8]: %d\n", rc);
       return 1;
     }
 
@@ -121,24 +121,24 @@ main (void)
 				    "rms", "436521", 10, "6767", &last_otp);
   if (rc != OATH_OK)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[9]: %d\n", rc);
       return 1;
     }
 
   /*
-    Run 'oathtool --totp --now=2006-12-07 00 -w10' to generate:
+    Run 'TZ=UTC oathtool --totp --now=2006-12-07 00 -w10' to generate:
 
-    140852
-    299833
-    044488
-    584072
-    000706
-    512368
-    094088
-    755942
-    936706
-    369736
-    787399
+    963013
+    068866
+    734019
+    038980
+    630208
+    533058
+    042289
+    046988
+    047407
+    892423
+    619507
    */
 
   /* Test completely invalid OTP */
@@ -146,70 +146,70 @@ main (void)
 				    "eve", "386397", 0, "4711", &last_otp);
   if (rc != OATH_BAD_PASSWORD)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[10]: %d\n", rc);
       return 1;
     }
 
   /* Test the next OTP but search window = 0. */
   rc = oath_authenticate_usersfile (CREDS,
-				    "eve", "299833", 0, NULL, &last_otp);
+				    "eve", "068866", 0, NULL, &last_otp);
   if (rc != OATH_INVALID_OTP)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[11]: %d\n", rc);
       return 1;
     }
 
   /* Test the next OTP with search window = 1. */
   rc = oath_authenticate_usersfile (CREDS,
-				    "eve", "299833", 1, NULL, &last_otp);
+				    "eve", "068866", 1, NULL, &last_otp);
   if (rc != OATH_OK)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[12]: %d\n", rc);
       return 1;
     }
 
   /* Test to replay last OTP. */
   rc = oath_authenticate_usersfile (CREDS,
-				    "eve", "299833", 1, NULL, &last_otp);
+				    "eve", "068866", 1, NULL, &last_otp);
   if (rc != OATH_REPLAYED_OTP)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[13]: %d\n", rc);
       return 1;
     }
 
   /* Test to replay previous OTP. */
   rc = oath_authenticate_usersfile (CREDS,
-				    "eve", "140852", 1, NULL, &last_otp);
+				    "eve", "963013", 1, NULL, &last_otp);
   if (rc != OATH_REPLAYED_OTP)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[14]: %d\n", rc);
       return 1;
     }
 
   /* Try an OTP in the future but outside search window. */
   rc = oath_authenticate_usersfile (CREDS,
-				    "eve", "369736", 1, NULL, &last_otp);
+				    "eve", "892423", 1, NULL, &last_otp);
   if (rc != OATH_INVALID_OTP)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[15]: %d\n", rc);
       return 1;
     }
 
   /* Try OTP in the future with good search window. */
   rc = oath_authenticate_usersfile (CREDS,
-				    "eve", "369736", 10, NULL, &last_otp);
+				    "eve", "892423", 10, NULL, &last_otp);
   if (rc != OATH_OK)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[16]: %d\n", rc);
       return 1;
     }
 
   /* Now try a rather old OTP within search window. */
   rc = oath_authenticate_usersfile (CREDS,
-				    "eve", "000706", 10, NULL, &last_otp);
+				    "eve", "630208", 10, NULL, &last_otp);
   if (rc != OATH_REPLAYED_OTP)
     {
-      printf ("oath_authenticate_usersfile: %d\n", rc);
+      printf ("oath_authenticate_usersfile[17]: %d\n", rc);
       return 1;
     }
 
