@@ -35,8 +35,8 @@
  * @output_otp: output buffer, must have room for the output OTP plus zero
  *
  * Generate a one-time-password using the time-variant TOTP algorithm
- * described in draft-mraihi-totp-timebased-07.  The input parameters
- * are taken as time values.
+ * described in RFC 6238.  The input parameters are taken as time
+ * values.
  *
  * The system parameter @time_step_size describes how long the time
  * window for each OTP is.  The recommended value is 30 seconds, and
@@ -80,6 +80,41 @@ oath_totp_generate (const char *secret,
 			     false, OATH_HOTP_DYNAMIC_TRUNCATION, output_otp);
 }
 
+/**
+ * oath_totp_validate:
+ * @secret: the shared secret string
+ * @secret_length: length of @secret
+ * @now: Unix time value to validate TOTP for
+ * @time_step_size: time step system parameter (typically 30)
+ * @start_offset: Unix time of when to start counting time steps (typically 0)
+ * @window: how many OTPs after/before start OTP to test
+ * @otp: the OTP to validate.
+ *
+ * Validate an OTP according to OATH TOTP algorithm per RFC 6238.
+ *
+ * Currently only OTP lengths of 6, 7 or 8 digits are supported.  This
+ * restrictions may be lifted in future versions, although some
+ * limitations are inherent in the protocol.
+ *
+ * Returns: Returns absolute value of position in OTP window (zero is
+ *   first position), or %OATH_INVALID_OTP if no OTP was found in OTP
+ *   window, or an error code.
+ *
+ * Since: 1.6.0
+ **/
+int
+oath_totp_validate (const char *secret,
+		    size_t secret_length,
+		    time_t now,
+		    unsigned time_step_size,
+		    time_t start_offset,
+		    size_t window,
+		    const char *otp)
+{
+  return oath_totp_validate2 (secret, secret_length, now, time_step_size,
+			      start_offset, window, NULL, otp);
+}
+
 /**
  * oath_totp_validate_callback:
  * @secret: the shared secret string
@@ -92,8 +127,7 @@ oath_totp_generate (const char *secret,
  * @strcmp_otp: function pointer to a strcmp-like function.
  * @strcmp_handle: caller handle to be passed on to @strcmp_otp.
  *
- * Validate an OTP according to OATH TOTP algorithm per
- * draft-mraihi-totp-timebased-07.
+ * Validate an OTP according to OATH TOTP algorithm per RFC 6238.
  *
  * Validation is implemented by generating a number of potential OTPs
  * and performing a call to the @strcmp_otp function, to compare the
@@ -131,6 +165,104 @@ oath_totp_validate_callback (const char *secret,
 			     size_t window,
 			     oath_validate_strcmp_function strcmp_otp,
 			     void *strcmp_handle)
+{
+  return oath_totp_validate2_callback (secret, secret_length, now,
+				       time_step_size, start_offset,
+				       digits, window, NULL,
+				       strcmp_otp, strcmp_handle);
+}
+
+/**
+ * oath_totp_validate2:
+ * @secret: the shared secret string
+ * @secret_length: length of @secret
+ * @now: Unix time value to validate TOTP for
+ * @time_step_size: time step system parameter (typically 30)
+ * @start_offset: Unix time of when to start counting time steps (typically 0)
+ * @window: how many OTPs after/before start OTP to test
+ * @otp_pos: output search position in search window (may be NULL).
+ * @otp: the OTP to validate.
+ *
+ * Validate an OTP according to OATH TOTP algorithm per RFC 6238.
+ *
+ * Currently only OTP lengths of 6, 7 or 8 digits are supported.  This
+ * restrictions may be lifted in future versions, although some
+ * limitations are inherent in the protocol.
+ *
+ * Returns: Returns absolute value of position in OTP window (zero is
+ *   first position), or %OATH_INVALID_OTP if no OTP was found in OTP
+ *   window, or an error code.
+ *
+ * Since: 1.10.0
+ **/
+int
+oath_totp_validate2 (const char *secret,
+		     size_t secret_length,
+		     time_t now,
+		     unsigned time_step_size,
+		     time_t start_offset,
+		     size_t window,
+		     int *otp_pos,
+		     const char *otp)
+{
+  return oath_totp_validate2_callback (secret, secret_length, now,
+				       time_step_size, start_offset,
+				       strlen (otp), window, otp_pos,
+				       _oath_strcmp_callback, (void *) otp);
+}
+
+/**
+ * oath_totp_validate2_callback:
+ * @secret: the shared secret string
+ * @secret_length: length of @secret
+ * @now: Unix time value to compute TOTP for
+ * @time_step_size: time step system parameter (typically 30)
+ * @start_offset: Unix time of when to start counting time steps (typically 0)
+ * @digits: number of requested digits in the OTP
+ * @window: how many OTPs after start counter to test
+ * @otp_pos: output search position in search window (may be NULL).
+ * @strcmp_otp: function pointer to a strcmp-like function.
+ * @strcmp_handle: caller handle to be passed on to @strcmp_otp.
+ *
+ * Validate an OTP according to OATH TOTP algorithm per RFC 6238.
+ *
+ * Validation is implemented by generating a number of potential OTPs
+ * and performing a call to the @strcmp_otp function, to compare the
+ * potential OTP against the given @otp.  It has the following
+ * prototype:
+ *
+ * int (*oath_validate_strcmp_function) (void *handle, const char *test_otp);
+ *
+ * The function should behave like strcmp, i.e., only ever return 0 on
+ * matches.
+ *
+ * This callback interface is useful when you cannot compare OTPs
+ * directly using normal strcmp, but instead for example only have a
+ * hashed OTP.  You would then typically pass in the hashed OTP in the
+ * @strcmp_handle and let your implementation of @strcmp_otp hash the
+ * test_otp OTP using the same hash, and then compare the results.
+ *
+ * Currently only OTP lengths of 6, 7 or 8 digits are supported.  This
+ * restrictions may be lifted in future versions, although some
+ * limitations are inherent in the protocol.
+ *
+ * Returns: Returns absolute value of position in OTP window (zero is
+ *   first position), or %OATH_INVALID_OTP if no OTP was found in OTP
+ *   window, or an error code.
+ *
+ * Since: 1.10.0
+ **/
+int
+oath_totp_validate2_callback (const char *secret,
+			      size_t secret_length,
+			      time_t now,
+			      unsigned time_step_size,
+			      time_t start_offset,
+			      unsigned digits,
+			      size_t window,
+			      int *otp_pos,
+			      oath_validate_strcmp_function strcmp_otp,
+			      void *strcmp_handle)
 {
   unsigned iter = 0;
   char tmp_otp[10];
@@ -153,7 +285,11 @@ oath_totp_validate_callback (const char *secret,
 	return rc;
 
       if (strcmp_otp (strcmp_handle, tmp_otp) == 0)
-	return iter;
+	{
+	  if (otp_pos)
+	    *otp_pos = iter;
+	  return iter;
+	}
 
       if (iter > 0)
 	{
@@ -167,48 +303,14 @@ oath_totp_validate_callback (const char *secret,
 	    return rc;
 
 	  if (strcmp_otp (strcmp_handle, tmp_otp) == 0)
-	    return iter;
+	    {
+	      if (otp_pos)
+		*otp_pos = -iter;
+	      return iter;
+	    }
 	}
     }
   while (window - iter++ > 0);
 
   return OATH_INVALID_OTP;
 }
-
-/**
- * oath_totp_validate:
- * @secret: the shared secret string
- * @secret_length: length of @secret
- * @now: Unix time value to validate TOTP for
- * @time_step_size: time step system parameter (typically 30)
- * @start_offset: Unix time of when to start counting time steps (typically 0)
- * @window: how many OTPs after/before start OTP to test
- * @otp: the OTP to validate.
- *
- * Validate an OTP according to OATH TOTP algorithm per
- * draft-mraihi-totp-timebased-07.
- *
- * Currently only OTP lengths of 6, 7 or 8 digits are supported.  This
- * restrictions may be lifted in future versions, although some
- * limitations are inherent in the protocol.
- *
- * Returns: Returns position in OTP window (zero is first position),
- *   or %OATH_INVALID_OTP if no OTP was found in OTP window, or an
- *   error code.
- *
- * Since: 1.6.0
- **/
-int
-oath_totp_validate (const char *secret,
-		    size_t secret_length,
-		    time_t now,
-		    unsigned time_step_size,
-		    time_t start_offset,
-		    size_t window,
-		    const char *otp)
-{
-  return oath_totp_validate_callback (secret, secret_length,
-				      now, time_step_size,
-				      start_offset, strlen (otp), window,
-				      _oath_strcmp_callback, (void *) otp);
-}
